@@ -68,7 +68,7 @@ def cli(ctx: MemfaultCliClickContext, **kwargs):
             httpclient_logger.log(logging.DEBUG, " ".join(args))
 
         http.client.print = httpclient_log  # type: ignore[attr-defined]
-        http.client.HTTPConnection.debuglevel = 1  # type: ignore[attr-defined]
+        http.client.HTTPConnection.debuglevel = 1
 
 
 def _do_upload_or_raise(
